8177015: STACK_SIZE_MINIMUM of 32k is not always enough for Mac OS X
authorcjplummer
Mon, 27 Mar 2017 11:53:44 -0700
changeset 46850 970a24772fe4
parent 46849 563fba072835
child 46851 8ca8d625d298
8177015: STACK_SIZE_MINIMUM of 32k is not always enough for Mac OS X Summary: Bump up minimum to 64k. Reviewed-by: dholmes, dcubed
jdk/src/java.base/share/native/libjli/java.c
jdk/test/tools/launcher/TooSmallStackSize.java
--- a/jdk/src/java.base/share/native/libjli/java.c	Wed Mar 22 20:36:49 2017 +0100
+++ b/jdk/src/java.base/share/native/libjli/java.c	Mon Mar 27 11:53:44 2017 -0700
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1995, 2016, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 1995, 2017, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -201,7 +201,7 @@
  * A minimum -Xss stack size suitable for all platforms.
  */
 #ifndef STACK_SIZE_MINIMUM
-#define STACK_SIZE_MINIMUM (32 * KB)
+#define STACK_SIZE_MINIMUM (64 * KB)
 #endif
 
 /*
--- a/jdk/test/tools/launcher/TooSmallStackSize.java	Wed Mar 22 20:36:49 2017 +0100
+++ b/jdk/test/tools/launcher/TooSmallStackSize.java	Mon Mar 27 11:53:44 2017 -0700
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2014, 2016, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2014, 2017, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -155,15 +155,21 @@
         checkStack("16k");
 
         /*
          * Try with a 32k stack size, which is the size that the launcher will
          * set to if you try setting to anything smaller. This should produce the same
          * result as setting to 16k if the fix for 6762191 is in place.
          */
-        String min_stack_allowed = checkStack("32k");
+        String min_stack_allowed = checkStack("64k");
 
         /*
          * Try again with a the minimum stack size that was given in the error message
          */
         checkMinStackAllowed(min_stack_allowed);
+
+        /*
+         * Try again with a size that is not OS page aligned. This is to help test that
+         * asserts added for 8176768 are not triggered.
+         */
+        checkMinStackAllowed("513k");
     }
 }
@@ -155,15 +155,21 @@
 
         /*
-         * Try with a 32k stack size, which is the size that the launcher will
+         * Try with a 64k stack size, which is the size that the launcher will
          * set to if you try setting to anything smaller. This should produce the same
          * result as setting to 16k if the fix for 6762191 is in place.